@@ -1011,10 +1011,10 @@ END
        "    },";
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i '/Send X-Catalyst header/a$ad' $pm_path");
-   ($stdout,$stderr)=$handle->cmd(
-       "${sudo}sed -i 's/\\\\(^Session$\\\\\)/    \\\\1/' $pm_path");
-   ($stdout,$stderr)=$handle->cmd(
-       "${sudo}sed -i 's/\\\\(^authentication =.*\\\\\)/    \\\\1/' $pm_path");
+   cmd_raw($handle,
+       "${sudo}sed -i 's/\\(^Session$\\\)/    \\1/' $pm_path");
+   cmd_raw($handle,
+       "${sudo}sed -i 's/\\(^authentication =.*\\\)/    \\1/' $pm_path");
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $pm_path");
